@@ -214,7 +214,7 @@ def submit_notebook(assignment=None, guest=False, websubmit=False):
             create = 1
         else:
             create = 0
-        src = base_url + "/GUI/manual_upload/" + assignment + "/" + urllib.parse.quote(author) + "?guest=" + create
+        src = base_url + "/GUI/manual_upload/" + assignment + "/" + urllib.parse.quote(author) + "?guest=" + str(create)
         if not websubmit:
             display(HTML(skins.HTML_MESSAGE_INPUT_REQUIRED))
         display(IFrame(src, 600, 100))
@@ -249,7 +249,7 @@ def submit_notebook(assignment=None, guest=False, websubmit=False):
             return False
 
 
-def send_group_workbook(assignment=None, emails=[]):
+def send_group_workbook(assignment=None, emails=[], skip_email_check = False):
     """
 
     :param assignment:
@@ -260,17 +260,24 @@ def send_group_workbook(assignment=None, emails=[]):
     global base_url
 
     # Check if valid emails are provided
+    emails_new = []
+    for email in emails:
+        if email != "":
+            emails_new.append(email)
+    emails=emails_new
+
+
     if (len(emails)==0):
         print("Please enter your email and run this code again.")
         return False
-
-    EMAIL_REGEX = re.compile(r"[^@]+@[^@]+\.[^@]+")
-    for i in range(len(emails)):
-        if not EMAIL_REGEX.match(emails[i]):
-            print(emails[i], "is not a valid email. If needed edit email and run this code again.")
+    if (skip_email_check == False):
+        EMAIL_REGEX = re.compile(r"[^@]+@[^@]+\.[^@]+")
+        for i in range(len(emails)):
+            if not EMAIL_REGEX.match(emails[i]):
+                print(emails[i], "is not a valid email. If needed edit email and run this code again.")
 
     # Encode emails for easy transfer
-    emails_json = json.dumps(emails);
+    emails_json = json.dumps(emails)
     emails_base64 = base64.b64encode(emails_json.encode("ascii"))
 
     try:
@@ -299,7 +306,7 @@ def send_group_workbook(assignment=None, emails=[]):
     xhttp.open("POST", "https://sss-data.minerva.community/ForumCode/submit/""" + str(assignment) + """",true);
     xhttp.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
     xhttp.send("rand=""" + str(
-        rand_code) + '&url=".concat(btoa(notebook_url),"&data=",notebook_url,"&emails=","' + emails_base64 + '"));'
+        rand_code) + '&url=".concat(btoa(notebook_url),"&data=",notebook_url,"&emails=","' + str(emails_base64, 'utf-8') + '"));'
     display(Javascript(js_submission_code))
 
     # Use UUID to check if submission was successful
@@ -320,13 +327,13 @@ def send_group_workbook(assignment=None, emails=[]):
             return False
     return True
 
-def send_grades(assignment=None, emails=[], grades=[]):
+def send_grades(assignment=None, emails=[], grades=[], skip_email_check = False):
     """
 
     :param assignment:
     :return:
     """
-    import re, json, base64
+    import re, json, base64,requests
     global ready
     global base_url
 
@@ -335,15 +342,22 @@ def send_grades(assignment=None, emails=[], grades=[]):
         print("Please enter your email and run this code again.")
         raise ValueError("No email provided: Please enter your email and run this code again.");
 
+    grades_new = []
+    for grade in grades:
+        if grade != None:
+            grades_new.append(grade)
+        else:
+            grades_new.append(" ")
+    grades = grades_new
     if (len(grades)==0):
         print("List of grades is empty. Did you run autograding cell?")
         raise ValueError("No grades provided! List of grades is empty. Did you run autograding cell?");
 
-
-    EMAIL_REGEX = re.compile(r"[^@]+@[^@]+\.[^@]+")
-    for i in range(len(emails)):
-        if not EMAIL_REGEX.match(emails[i]):
-            print(emails[i], "is not a valid email. If needed edit email and run this code again.")
+    if (skip_email_check == False):
+        EMAIL_REGEX = re.compile(r"[^@]+@[^@]+\.[^@]+")
+        for i in range(len(emails)):
+            if not EMAIL_REGEX.match(emails[i]):
+                print(emails[i], "is not a valid email (see variable email"+str(i+1)+"). If needed edit email and run this code again.")
 
     # Encode emails for easy transfer
     emails_json = json.dumps(emails)
@@ -356,10 +370,11 @@ def send_grades(assignment=None, emails=[], grades=[]):
     import requests
     values = {'email': emails_base64, 'assignment': assignment, "grades": grades_base64}
     try:
-        r = requests.post(base_url + "/Notebook/grades", files=files, data=values)
+        r = requests.post(base_url + "/ForumCode/grades", data=values)
         if (str(r.content, 'utf-8', 'ignore')[0] == "Y"):
             return True
         else:
+            print(str(r.content, 'utf-8', 'ignore'))
             return False
     except:
         print("Connection Failed")
@@ -404,11 +419,11 @@ def send_grades_js(assignment=None, grades=[]):
     xhttp.open("POST", "https://sss-data.minerva.community/ForumCode/grades_js/""" + str(assignment) + """",true);
     xhttp.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
     xhttp.send("rand=""" + str(
-        rand_code) + '&url=".concat(btoa(notebook_url),"&data=",notebook_url,"&grades=","' + grades_base64 + '"));'
+        rand_code) + '&url=".concat(btoa(notebook_url),"&data=",notebook_url,"&grades=","' + str(grades_base64,'utf-8') + '"));'
     display(Javascript(js_submission_code))
     return True
 
-def send_notebook(assignment=None, guest=False, websubmit=False, grades=False, makeup=False, emails=[]):
+def send_notebook(assignment=None, guest=True, websubmit=False, grades=False, makeup=False, emails=[]):
     """
 
     :param assignment:
@@ -417,6 +432,7 @@ def send_notebook(assignment=None, guest=False, websubmit=False, grades=False, m
     global ready
     global base_url
     global log
+    import json, base64
 
     # Encode emails for easy transfer
     emails_json = json.dumps(emails)
@@ -432,7 +448,7 @@ def send_notebook(assignment=None, guest=False, websubmit=False, grades=False, m
         return False
     else:
         if guest:
-            author = json.dumps(emails_base64)
+            author = emails_base64
         else:
             author = base64.b64encode(json.dumps([cfg.email]).encode("ascii"))
 
@@ -530,10 +546,10 @@ def send_notebook(assignment=None, guest=False, websubmit=False, grades=False, m
             create = 1
         else:
             create = 0
-        src = base_url + "/GUI/manual_upload/" + assignment + "/" + urllib.parse.quote(author) + "?guest=" + create
+        src = base_url + "/GUI/manual_upload/" + assignment + "/" + urllib.parse.quote(author) + "?guest=" + str(create)
         if not websubmit:
             display(HTML(skins.HTML_MESSAGE_INPUT_REQUIRED))
-        display(IFrame(src, 600, 100))
+        display(IFrame(src, 600, 200))
     else:
         display(Javascript(skins.JS_PROGRESS_BAR_FAST_STEP))
         display(Javascript(skins.JS_PROGRESS_BAR_STEPS))
@@ -544,8 +560,7 @@ def send_notebook(assignment=None, guest=False, websubmit=False, grades=False, m
             if (str(r.content, 'utf-8', 'ignore')[0] == "Y"):
 
                 display(HTML("""<div class="alert alert-block alert-success">
-        <b>Upload successful!</b> You can view your submitted notebook on """ + '<a target="_blank" href="https://nbviewer.jupyter.org/urls/' + base_url.replace(
-                    "https://", "").replace("http://", "") + "/uploads/" + str(r.content, 'utf-8', 'ignore')[1:] + '"' + """ class="alert-link"> nbviewer.</a>
+        <b>Upload successful!</b>
         </div>"""))
                 display(Javascript(skins.JS_PROGRESS_BAR_FINAL))
 
